@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 class TupleActionProcessorDelegateABC(metaclass=ABCMeta):
     @abstractmethod
     def processTupleAction(self, tupleAction: TupleActionABC) -> Deferred:
-        """ Process Tuple Action
+        """Process Tuple Action
 
         The method generates the vortexMsg for the vortex to send.
 
@@ -29,12 +29,15 @@ class TupleActionProcessorDelegateABC(metaclass=ABCMeta):
 
 
 class TupleActionProcessor:
-    def __init__(self, tupleActionProcessorName: str,
-                 additionalFilt: Optional[Dict] = None,
-                 defaultDelegate: Optional[TupleActionProcessorDelegateABC] = None,
-                 acceptOnlyFromVortex: Optional[Union[str,tuple]] = None,
-                 usedForProxy__=False) -> None:
-        """ Constructor
+    def __init__(
+        self,
+        tupleActionProcessorName: str,
+        additionalFilt: Optional[Dict] = None,
+        defaultDelegate: Optional[TupleActionProcessorDelegateABC] = None,
+        acceptOnlyFromVortex: Optional[Union[str, tuple]] = None,
+        usedForProxy__=False,
+    ) -> None:
+        """Constructor
 
         :param tupleActionProcessorName: The name of this observable
 
@@ -49,33 +52,45 @@ class TupleActionProcessor:
         self._tupleActionProcessorName = tupleActionProcessorName
         self._defaultDelegate = defaultDelegate
 
-        self._tupleProcessorsByTupleName: Dict[str, TupleActionProcessorDelegateABC] = {}
+        self._tupleProcessorsByTupleName: Dict[
+            str, TupleActionProcessorDelegateABC
+        ] = {}
 
         if not usedForProxy__:
-            self._filt = dict(name=tupleActionProcessorName,
-                              key="tupleActionProcessorName")
+            self._filt = dict(
+                name=tupleActionProcessorName, key="tupleActionProcessorName"
+            )
 
             if additionalFilt:
                 self._filt.update(additionalFilt)
 
-            self._endpoint = PayloadEndpoint(self._filt, self._process,
-                                             acceptOnlyFromVortex=acceptOnlyFromVortex)
+            self._endpoint = PayloadEndpoint(
+                self._filt,
+                self._process,
+                acceptOnlyFromVortex=acceptOnlyFromVortex,
+            )
 
-    def setDelegate(self, tupleName: str, processor: TupleActionProcessorDelegateABC):
-        """ Add Tuple Action Processor Delegate
+    def setDelegate(
+        self, tupleName: str, processor: TupleActionProcessorDelegateABC
+    ):
+        """Add Tuple Action Processor Delegate
 
         :param tupleName: The tuple name to process actions for.
         :param processor: The processor to use for processing this tuple name.
 
         """
-        assert not tupleName in self._tupleProcessorsByTupleName, (
-                "TupleActionProcessor:%s, Tuple name %s is already registered" %
-                (self._tupleActionProcessorName, tupleName))
+        assert (
+            not tupleName in self._tupleProcessorsByTupleName
+        ), "TupleActionProcessor:%s, Tuple name %s is already registered" % (
+            self._tupleActionProcessorName,
+            tupleName,
+        )
 
         assert isinstance(processor, TupleActionProcessorDelegateABC), (
-                "TupleActionProcessor:%s, provider must be an"
-                " instance of TupleActionProcessorDelegateABC"
-                % self._tupleActionProcessorName)
+            "TupleActionProcessor:%s, provider must be an"
+            " instance of TupleActionProcessorDelegateABC"
+            % self._tupleActionProcessorName
+        )
 
         self._tupleProcessorsByTupleName[tupleName] = processor
 
@@ -90,26 +105,39 @@ class TupleActionProcessor:
         self._endpoint.shutdown()
 
     @inlineCallbacks
-    def _process(self, payloadEnvelope: PayloadEnvelope,
-                 sendResponse: SendVortexMsgResponseCallable, **kwargs):
-        """ Process the Payload / Tuple Action
-        """
+    def _process(
+        self,
+        payloadEnvelope: PayloadEnvelope,
+        sendResponse: SendVortexMsgResponseCallable,
+        **kwargs
+    ):
+        """Process the Payload / Tuple Action"""
 
         payload = yield payloadEnvelope.decodePayloadDefer()
 
-        assert len(payload.tuples) == 1, (
-                "TupleActionProcessor:%s Expected 1 tuples, received %s" % (
-            self._tupleActionProcessorName, len(payload.tuples)))
+        assert (
+            len(payload.tuples) == 1
+        ), "TupleActionProcessor:%s Expected 1 tuples, received %s" % (
+            self._tupleActionProcessorName,
+            len(payload.tuples),
+        )
 
         tupleAction = payload.tuples[0]
 
-        self._processTupleAction(payloadEnvelope.filt, sendResponse, tupleAction)
+        self._processTupleAction(
+            payloadEnvelope.filt, sendResponse, tupleAction
+        )
 
-    def _processTupleAction(self, payloadEnvelopeFilt, sendResponse, tupleAction):
+    def _processTupleAction(
+        self, payloadEnvelopeFilt, sendResponse, tupleAction
+    ):
 
-        assert isinstance(tupleAction, TupleActionABC), \
-            "TupleActionProcessor:%s Expected TupleAction, received %s" \
-            % (self._tupleActionProcessorName, tupleAction.__class__)
+        assert isinstance(
+            tupleAction, TupleActionABC
+        ), "TupleActionProcessor:%s Expected TupleAction, received %s" % (
+            self._tupleActionProcessorName,
+            tupleAction.__class__,
+        )
 
         tupleName = tupleAction.tupleName()
         processor = self._tupleProcessorsByTupleName.get(tupleName)
@@ -122,12 +150,21 @@ class TupleActionProcessor:
         else:
             raise Exception("No delegate registered for %s" % tupleName)
         d = self._customMaybeDeferred(delegate, tupleAction)
-        d.addCallback(self._callback, payloadEnvelopeFilt, tupleName, sendResponse)
-        d.addErrback(self._errback, payloadEnvelopeFilt, tupleName, sendResponse)
+        d.addCallback(
+            self._callback, payloadEnvelopeFilt, tupleName, sendResponse
+        )
+        d.addErrback(
+            self._errback, payloadEnvelopeFilt, tupleName, sendResponse
+        )
 
     @inlineCallbacks
-    def _callback(self, result, replyFilt: dict, tupleName: str,
-                  sendResponse: SendVortexMsgResponseCallable):
+    def _callback(
+        self,
+        result,
+        replyFilt: dict,
+        tupleName: str,
+        sendResponse: SendVortexMsgResponseCallable,
+    ):
 
         if not isinstance(result, list):
             result = [result]
@@ -139,15 +176,24 @@ class TupleActionProcessor:
             yield sendResponse(vortexMsg)
 
         except Exception as e:
-            logger.error("Failed to send TupleAction response for %s", tupleName)
+            logger.error(
+                "Failed to send TupleAction response for %s", tupleName
+            )
             logger.exception(e)
 
     @inlineCallbacks
-    def _errback(self, result: Failure, replyFilt: dict, tupleName: str,
-                 sendResponse: SendVortexMsgResponseCallable):
+    def _errback(
+        self,
+        result: Failure,
+        replyFilt: dict,
+        tupleName: str,
+        sendResponse: SendVortexMsgResponseCallable,
+    ):
 
-        logger.error("TupleActionProcessor:%s Failed to process TupleActon",
-                     self._tupleActionProcessorName)
+        logger.error(
+            "TupleActionProcessor:%s Failed to process TupleActon",
+            self._tupleActionProcessorName,
+        )
 
         vortexLogFailure(result, logger)
         failureMessage = result.getErrorMessage()
@@ -158,9 +204,11 @@ class TupleActionProcessor:
             yield sendResponse(vortexMsg)
 
         except Exception as e:
-            logger.error("Failed to send TupleAction response for %s\n%s",
-                         tupleName,
-                         failureMessage)
+            logger.error(
+                "Failed to send TupleAction response for %s\n%s",
+                tupleName,
+                failureMessage,
+            )
             logger.exception(e)
 
     def _customMaybeDeferred(self, f, *args, **kw):
