@@ -13,9 +13,13 @@ def makeTestTupleData(count=5):
     tuples = []
     for num in range(count):
         uniStr = "#%s double hyphen :-( — “fancy quotes”" % num
-        tuples.append(TestTuple(aInt=num,
-                              aBoolTrue=bool(num % 2),
-                              aString="This is tuple #%s" % num,
-                              aStrWithUnicode=uniStr))
+        tuples.append(
+            TestTuple(
+                aInt=num,
+                aBoolTrue=bool(num % 2),
+                aString="This is tuple #%s" % num,
+                aStrWithUnicode=uniStr,
+            )
+        )
 
     return tuples
